#!/usr/bin/env python

from setuptools import setup

NULL_PROVIDER_VERSION = "2.1.2"

RELEASE_VERSION = "1"

__version__ = f"{NULL_PROVIDER_VERSION}.post{RELEASE_VERSION}"

try:
    from wheel.bdist_wheel import bdist_wheel as _bdist_wheel
    class bdist_wheel(_bdist_wheel):
        def finalize_options(self):
            _bdist_wheel.finalize_options(self)
            self.root_is_pure = False
except ImportError:
    bdist_wheel = None

setup(
    name="terraform-null-provider-wrapper",
    version=__version__,
    description="Python wrapper for Terraform Null Provider",
    author="Iman Azari",
    author_email="azari@mahsan.co",
    url="https://github.com/imanazari70/terraform-null-provider-wrapper",
    py_modules=["terraform_null_provider"],
    data_files=[
        (f"/root/.terraform.d/plugins/registry.terraform.io/hashicorp/null/{NULL_PROVIDER_VERSION}/linux_amd64", [f"lib/terraform-provider-null_v{NULL_PROVIDER_VERSION}_x4"]),
    ],
    cmdclass={'bdist_wheel': bdist_wheel},
    entry_points={
        "console_scripts": [
            "tf-null-provider-download = terraform_null_provider:download",
        ]
    },
)
